@@ -5,12 +5,11 @@
 #' @param ... Additional args.
 #'
 #' @return Uses the blueprint to construct the results of the statistical
-#'   analysis.
+#'   analysis. Outputs a [tibble][tibble::tibble-package].
 #' @export
 #'
 #' @examples
 #'
-#' library(magrittr)
 #' design(iris, 'cor') %>%
 #'  add_settings() %>%
 #'  add_variables('xvars', c('Sepal.Length', 'Sepal.Width')) %>%
@@ -34,6 +33,12 @@
 #'  add_variables('xvars', c('Petal.Length', 'Petal.Width')) %>%
 #'  construct()
 #'
+#' design(iris, 'pls') %>%
+#'  add_settings() %>%
+#'  add_variables('yvars', c('Sepal.Length', 'Sepal.Width')) %>%
+#'  add_variables('xvars', c('Petal.Length', 'Petal.Width')) %>%
+#'  construct()
+#'
 construct <- function(data, ..., na.rm = TRUE) {
     UseMethod("construct", data)
 }
@@ -48,12 +53,6 @@ construct.gee_bp <- function(data, na.rm = TRUE, ...) {
     specs <- attributes(data)$specs
     specs_integrity(data, specs)
 
-    if (length(c(specs$vars$yvars, specs$vars$xvars)) >= 100)
-        stop(
-            'There are too many y and/or x variables to loop through, ',
-            'please split the construction up (see vignette for more details).'
-        )
-
     f <- function(data, specs, form) {
         # Have to add these because I think geeglm doesn't reference them
         # explicitly inside its function
@@ -75,19 +74,19 @@ construct.gee_bp <- function(data, na.rm = TRUE, ...) {
         nsize <- summary(mod)$clusz
 
         data.frame(
+            Yterms = all.vars(form)[1],
+            Xterms = all.vars(form)[2],
             tidied,
             sample.total = sum(nsize),
             sample.max = max(nsize),
-            sample.min = min(nsize)
+            sample.min = min(nsize),
+            stringsAsFactors = FALSE
         )
     }
     form <- regression_formula(specs)
-    tool <- lazyeval::interp(~f(., specs = specs, form = form),
-                                          f = f,
-                                          specs = specs,
-                                          form = form)
 
-    construction_base(data = data, specs = specs, tool = tool, na.rm = na.rm)
+    construction_base(data = data, specs = specs, tool = f,
+                       formulas = form$formulas, na.rm = na.rm)
 }
 
 #' @export
@@ -95,7 +94,7 @@ construct.glm_bp <- function(data, na.rm = TRUE, ...) {
     specs <- attributes(data)$specs
     specs_integrity(data, specs)
 
-    f <- function(data, specs, form) {
+    tool <- function(data, specs, form) {
         mod <- stats::glm(form,
                           data = data,
                           family = specs$family)
@@ -103,16 +102,18 @@ construct.glm_bp <- function(data, na.rm = TRUE, ...) {
             broom::tidy(mod,
                         conf.int = specs$conf.int,
                         conf.level = specs$conf.level)
-        data.frame(tidied,
-                   sample.size = nrow(mod$model))
+        data.frame(
+            Yterms = all.vars(form)[1],
+            Xterms = all.vars(form)[2],
+            tidied,
+            sample.size = nrow(mod$model),
+            stringsAsFactors = FALSE
+        )
     }
     form <- regression_formula(specs)
-    tool <- lazyeval::interp(~f(., specs = specs, form = form),
-                                          f = f,
-                                          specs = specs,
-                                          form = form)
 
-    construction_base(data = data, specs = specs, tool = tool, na.rm = na.rm)
+    construction_base(data = data, specs = specs, tool = tool,
+                      formulas = form$formulas, na.rm = na.rm)
 }
 
 #' @export
@@ -158,22 +159,34 @@ construct.t.test_bp <- function(data, na.rm = TRUE, ...) {
     specs <- attributes(data)$specs
     specs_integrity(data, specs)
 
-    f <- function(data, specs) {
-        broom::tidy(stats::t.test(data$YtermValues, data$XtermValues,
-                                  paired = specs$paired))
+    tool <- function(data, specs, form) {
+        y <- form[1]
+        x <- form[2]
+        results <- stats::t.test(x = data[[x]],
+                                 y = data[[y]],
+                                 paired = specs$paired)
+        results <- broom::tidy(results)
+        data.frame(
+            Yterms = y,
+            Xterms = x,
+            results,
+            stringsAsFactors = FALSE
+        )
     }
-    tool <- lazyeval::interp(~f(., specs = specs),
-                             f = f,
-                             specs = specs)
 
-    construction_base(data = data, specs = specs, tool = tool, na.rm = na.rm)
+    form <- regression_formula(specs)
+    # convert so that each x-y pair is a column
+    form <- dplyr::as_tibble(t(form$variables), .name_repair = make.names)
+    construction_base(data = data, specs = specs, tool = tool,
+                      formulas = form, na.rm = na.rm)
 }
 
+#' @export
 construct.pls_bp <- function(data, ...) {
 
-    if (!requireNamespace('pls'))
-        stop('pls is needed for this analysis, please install it',
-             call. = FALSE)
+    if (!requireNamespace('pls', quietly = TRUE)) {
+        stop('Please install the pls package to run this analysis.')
+    }
 
     specs <- attributes(data)$specs
     specs_integrity(data, specs, stat = 'pls')
@@ -189,6 +202,7 @@ construct.pls_bp <- function(data, ...) {
     if (is.null(specs$ncomp))
         specs$ncomp <- length(specs$vars$xvars)
 
+    # TODO: This or use data in the pls instead?
     Y <- as.matrix(d[, specs$vars$yvars])
     X <- as.matrix(d[, specs$vars$xvars])
     results <- pls::plsr(Y ~ X, scale = specs$scale, ncomp = specs$ncomp)
